@@ -16,6 +16,8 @@ pub struct AWSAPICall<I = Value, O = Value> {
     pub user_agent: String,
     pub request_parameters: I,
     pub response_elements: O,
+    #[serde(default)]
+    pub additional_event_data: Option<Value>,
     #[serde(rename = "requestID")]
     pub request_id: String,
     #[serde(rename = "eventID")]
